/***************************************************************************//**
 * @file    bitwise.h
 * @brief   Bitwise operations
 * 
 * @details Implements bitwise operations to set and clear bits.
 * @author  Ángel Grover Pérez Muñoz, Manuel Nieto
 ******************************************************************************/

#pragma once

/***************************************************************************//**
 * Macros
 ******************************************************************************/

/**
 * @brief Sets bit from PORT to 1 (SET).
 */
#define sbi(PORT, bit)  PORT |= (1 << bit)

/**
 * @brief Sets bit from PORT to 0 (CLEAR).
 */
#define cbi(PORT, bit)  PORT &= ~(1 << (bit))

/**
 * @brief Sets value to bit "bit" from port "PORT".
 */
#define setbit(VALUE, PORT, bit)  ((VALUE) ? /*1*/ (PORT |= (1 << (bit))) : /*0*/ (PORT &= ~(1 << (bit))))

/**
 * @brief Get value from bit "bit" from "VALUE"
 */
#define getbit(VALUE, bit) (((VALUE) >> (bit)) & 0x01)